==> haskell-x509-store-1.6.9-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-store
version:              1.6.9
visibility:           public
id:                   x509-store-1.6.9-69Uyat9Cffg6LlDYKUxyFK
key:                  x509-store-1.6.9-69Uyat9Cffg6LlDYKUxyFK
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  7dd97f64936a2d04dd0f65558dd4eced
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.0.2/site-local/x509-store-1.6.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/x509-store-1.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509-store
hs-libraries:         HSx509-store-1.6.9-69Uyat9Cffg6LlDYKUxyFK
depends:
    asn1-encoding-0.9.6-G4hlcZ41FTABNgkoRtyjSi
    asn1-types-0.3.4-FStAjRCRoIGI1Dy14esdZc base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.30-6t1O7psLMh7IeVK47IhUa0 directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-2K69S1TahqSIqX4DEdQ7Bg
    x509-1.7.7-H0bV2POXrq5IWLbufLAm

haddock-interfaces:   /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html:         /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.9-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-store
version:              1.6.9
visibility:           public
id:                   x509-store-1.6.9-HyVueWhDI69IBWN9x1MpRQ
key:                  x509-store-1.6.9-HyVueWhDI69IBWN9x1MpRQ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  ca9368f14fef4aa2944f0789eb164031
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.0.2/site-local/x509-store-1.6.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/x509-store-1.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509-store
hs-libraries:         HSx509-store-1.6.9-HyVueWhDI69IBWN9x1MpRQ
depends:
    asn1-encoding-0.9.6-Bt6KnevcKfmGxeK3CjmKEN
    asn1-types-0.3.4-IikFNQoadxyGthhZz2KwGc base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.30-ATVl7QapHZS9RRZ445MyBy directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-Al9qUzRnvkUD677LHeSnUa
    x509-1.7.7-8lspvYsrbN7qz2j8QSVXN

haddock-interfaces:   /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html:         /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
